#

##

###

##

##

    		instrument

    	start
    		./instrument layer start

    		options
    			recycling instrument layer start --name instrument-1
    			recycling instrument layer start --name instrument-1 --layer-port 50000 --mongo-port 50001

    			recycling instrument layer move make-vibe
    			recycling instrument layer move list-vibes

    	HTTP(S) API
    		http://localhost:50000/

    	structure
    		[dir] instrument-1
    			[dir] moon
    				db:wallet
    					collection:vibe [{
    						"public": {
    							"hexadecimal string": ""
    						},
    						"private": {
    							"hexadecimal string": ""
    						},
    						"seed": {
    							"hexadecimal string": ""
    						}
    					}]

    		names:
    			./names

    		agenda:
    			./__agenda/agenda